Package: lg
Title: Locally Gaussian Distributions: Estimation and Methods
Version: 0.4.1
Authors@R: person("Håkon", "Otneim", email = "hakon.otneim@nhh.no", role = c("aut", "cre"))
Description: An implementation of locally Gaussian distributions. It provides methods for
    implementing locally Gaussian multivariate density estimation, conditional density 
    estimation, various independence tests for iid and time series data, a test for conditional 
    independence and a test for financial contagion.
Depends: R (>= 3.4)
License: GPL-3
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.1.1
Suggests: testthat
Imports: mvtnorm, localgauss, logspline, ggplot2, ks, np, tseries
NeedsCompilation: no
Packaged: 2019-12-05 11:05:29 UTC; hakon
Author: Håkon Otneim [aut, cre]
Maintainer: Håkon Otneim <hakon.otneim@nhh.no>
Repository: CRAN
Date/Publication: 2019-12-05 12:40:02 UTC
Built: R 4.4.0; ; 2024-04-28 14:36:07 UTC; unix
