# Generated by roxygen2: do not edit by hand

export(bw_select)
export(bw_select_cv_bivariate)
export(bw_select_cv_trivariate)
export(bw_select_cv_univariate)
export(bw_select_plugin_multivariate)
export(bw_select_plugin_univariate)
export(bw_simple)
export(ci_test)
export(clg)
export(cont_test)
export(corplot)
export(dlg)
export(dlg_bivariate)
export(dlg_marginal)
export(dlg_marginal_wrapper)
export(dlg_trivariate)
export(ind_test)
export(lg_main)
export(partial_cor)
importFrom(stats,cov)
importFrom(stats,dnorm)
importFrom(stats,na.omit)
importFrom(stats,optim)
importFrom(stats,optimise)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,splinefun)
importFrom(utils,combn)
importFrom(utils,tail)
